@@ -10,15 +10,10 @@ PDL development and is often used from within Makefile.PL's.
 =head1 SYNOPSIS
 
    use PDL::Core::Dev;
-   if ($^O =~ /win32/i) {
-    warn "Win32 systems not yet supported. Will not build PDL::IO::Browser";
-    write_dummy_make(unsupported('PDL::XXX','win32'));
-    return;
-   }
 
 =head1 FUNCTIONS
 
-=cut   
+=cut
 
 # Stuff used in development/install environment of PDL Makefile.PL's
 # - not part of PDL itself.
@@ -29,7 +24,7 @@ use English; require Exporter;
 
 @ISA    = qw( Exporter );
 
-@EXPORT = qw( isbigendian genpp %PDL_DATATYPES 
+@EXPORT = qw( isbigendian genpp %PDL_DATATYPES
 	     PDL_INCLUDE PDL_TYPEMAP
 	     PDL_AUTO_INCLUDE PDL_BOOT
 		 PDL_INST_INCLUDE PDL_INST_TYPEMAP
@@ -113,6 +108,37 @@ sub whereami_inst {
    return undef;
 }
 
+#
+# To access PDL's configuration use %PDL::Config. Makefile.PL has been set up
+# to create this variable so it is available during 'perl Makefile.PL' and
+# it can be eval-ed during 'make'
+#
+unless ( defined %PDL::Config ) {
+
+    # look for the distribution and then the installed version
+    # (a manual version of whereami_any)
+    #
+    my $dir;
+    $dir = whereami(1);
+    if ( defined $dir ) {
+	$dir = abs_path($dir . "/Core");
+    } else {
+	# as no argument given whereami_inst will die if it fails
+        # (and it also returns a slightly different path than whereami(1)
+        #  does, since it does not include "/PDL")
+	#
+	$dir = whereami_inst;
+	$dir = abs_path($dir . "/PDL");
+    }
+
+    my $dir2 = $dir;
+    $dir2 =~ s/\}/\\\}/g;
+    eval sprintf('require q{%s/Config.pm};', $dir2);
+
+    die "Unable to find PDL's configuration info\n [$@]"
+	if $@;
+}
+
 # Data types to C types mapping
 # get the map from Types.pm
 {
@@ -132,10 +158,10 @@ sub whereami_inst {
 }
 PDL::Types->import();
 
-my $inc = defined $::PDL_CONFIG{MALLOCDBG}->{include} ?
-  "$::PDL_CONFIG{MALLOCDBG}->{include}" : '';
-my $libs = defined $::PDL_CONFIG{MALLOCDBG}->{libs} ?
-  "$::PDL_CONFIG{MALLOCDBG}->{libs}" : '';
+my $inc = defined $PDL::Config{MALLOCDBG}->{include} ?
+  "$PDL::Config{MALLOCDBG}->{include}" : '';
+my $libs = defined $PDL::Config{MALLOCDBG}->{libs} ?
+  "$PDL::Config{MALLOCDBG}->{libs}" : '';
 
 %PDL_DATATYPES = ();
 foreach $key (keys %PDL::Types::typehash) {
@@ -203,14 +229,14 @@ sub isbigendian {
 #
 #     case PDL_L:
 #        {
-#           long *xx = x.data;
+#           PDL_Long *xx = x.data;
 #           for(i=0; i<nvals; i++)
 #              xx[i] = i/nvals;
 #        }break;
 #
 #     case PDL_F:
 #        {
-#           float *xx = x.data;
+#           PDL_Float *xx = x.data;
 #
 #       .... etc. .....
 #
@@ -387,6 +413,9 @@ $pref\$(OBJ_EXT): $pref.c
 
 # This is the function to be used outside the PDL tree.
 sub pdlpp_postamble {
+      # This sub breaks dmake if called. Thankfully, so far, dmake has not needed this
+	# sub (even when it does get called) - so simply have it return nothing:
+	if($Config{make} eq 'dmake') {return ""}
 	join '',map { my($src,$pref,$mod) = @$_;
 	my $w = whereami_any();
 	$w =~ s%/((PDL)|(Basic))$%%;  # remove the trailing subdir
@@ -409,10 +438,10 @@ sub pdlpp_stdargs_int {
  my($rec) = @_;
  my($src,$pref,$mod) = @$rec;
  my $w = whereami();
- my $malloclib = exists $PDL_CONFIG{MALLOCDBG}->{libs} ?
-   $PDL_CONFIG{MALLOCDBG}->{libs} : '';
- my $mallocinc = exists $PDL_CONFIG{MALLOCDBG}->{include} ?
-   $PDL_CONFIG{MALLOCDBG}->{include} : '';
+ my $malloclib = exists $PDL::Config{MALLOCDBG}->{libs} ?
+   $PDL::Config{MALLOCDBG}->{libs} : '';
+ my $mallocinc = exists $PDL::Config{MALLOCDBG}->{include} ?
+   $PDL::Config{MALLOCDBG}->{include} : '';
  return (
  	%::PDL_OPTIONS,
 	 'NAME'  	=> $mod,
@@ -453,7 +482,9 @@ sub write_dummy_make {
   require IO::File;
     my ($msg) = @_;
     print STDERR "writing dummy Makefile\n";
-    my $fh = new IO::File "> Makefile" or die "can't open Makefile";
+    my $fh = new IO::File "> Makefile" or die "Can't open dummy Makefile: $!";
+
+if($^O !~ /mswin32/i) {
     print $fh <<"EOT";
 fred:
 	\@echo \"****\"
@@ -471,7 +502,28 @@ realclean ::
 	rm -rf Makefile Makefile.old
 
 EOT
-    close($fh);
+}
+
+else { # It's Win32
+    print $fh <<"EOT";
+fred:
+	\@echo \"****\"
+	\@echo \"$msg\"
+	\@echo \"****\"
+
+all: fred
+
+test: fred
+
+clean ::
+	-ren Makefile Makefile.old <NUL
+
+realclean ::
+	del /F /Q Makefile Makefile.old <NUL
+
+EOT
+}
+   close($fh) or die "Can't close dummy Makefile: $!";
 }
 
 sub getcyglib {
@@ -577,8 +629,8 @@ sub trylink {
   # check if MakeMaker should be used to preprocess the libs
   for my $key(keys %$opt) {$opt->{lc $key} = $opt->{$key}}
   my $mmprocess = exists $opt->{makemaker} && $opt->{makemaker};
-  my $hide = exists $opt->{hide} ? $opt->{hide} : 
-    exists $::PDL_CONFIG{HIDE_TRYLINK} ? $::PDL_CONFIG{HIDE_TRYLINK} : 1;
+  my $hide = exists $opt->{hide} ? $opt->{hide} :
+    exists $PDL::Config{HIDE_TRYLINK} ? $PDL::Config{HIDE_TRYLINK} : 1;
   my $clean = exists $opt->{clean} ? $opt->{clean} : 1;
   if ($mmprocess) {
       require ExtUtils::MakeMaker;
@@ -593,11 +645,17 @@ sub trylink {
 
   print "     Trying $txt...\n     " unless $txt =~ /^\s*$/;
 
-  my $HIDE = ($^O =~ /MSWin/) || !$hide ? '' : '>/dev/null 2>&1'; 
-  my $td = $^O =~ /MSWin/ ? 'TEMP' : 'tmp';
-  my $tempd = defined $ENV{TEMP} ? $ENV{TEMP} :
-            defined $ENV{TMP} ? $ENV{TMP} :
-                           &$cdir($fs->rootdir,$td);
+  my $HIDE = !$hide ? '' : '>/dev/null 2>&1';
+  if($^O =~ /mswin32/i) {$HIDE = '>NUL 2>&1'}
+
+  my $tempd;
+
+  # Using dmake on Win32 requires special consideration.
+  if($Config{make} eq 'dmake') {$tempd = File::Spec->tmpdir()}
+  else {
+    $tempd = $PDL::Config{TEMPDIR} ||
+    die "TEMPDIR not found in \%PDL::CONFIG";
+    }
 
   my ($tc,$te) = map {&$cfile($tempd,"testfile$_")} ('.c','');
   open FILE,">$tc" or die "couldn't open testfile `$tc' for writing";
@@ -617,7 +675,7 @@ EOF
   close FILE;
   # print "test prog:\n$prog\n";
   # make sure we can overwrite the executable. shouldn't need this,
-  # but if it fails and HIDE is on, the user will never see the error.	 
+  # but if it fails and HIDE is on, the user will never see the error.
   open(T, ">$te") or die( "unable to write to test executable `$te'");
   close T;
   print "$Config{cc} $cflags -o $te $tc $libs $HIDE ...\n" unless $hide;
